summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAlexander Couzens <lynxis@fe80.eu>2016-07-30 21:53:50 +0200
committerHolger Levsen <holger@layer-acht.org>2016-08-02 16:24:19 +0200
commit8b2041c98b2a9baab95174dc4b34711e8817d2c7 (patch)
tree76b9d0b066526a1274759322b666605de174ef68
parent35b8965f04802f60f1873f3f606b0efeaf16a837 (diff)
downloadjenkins.debian.net-8b2041c98b2a9baab95174dc4b34711e8817d2c7.tar.xz
Revert "reproducible/openwrt|lede: fixup node_wrapper usage"
This reverts commit 8d586d5c9968778c934996aa59626635fc20b99f. Signed-off-by: Holger Levsen <holger@layer-acht.org>
-rwxr-xr-xbin/jenkins_node_wrapper.sh8
-rwxr-xr-xbin/reproducible_lede.sh7
-rwxr-xr-xbin/reproducible_openwrt.sh7
-rw-r--r--bin/reproducible_openwrt_common.sh13
4 files changed, 19 insertions, 16 deletions
diff --git a/bin/jenkins_node_wrapper.sh b/bin/jenkins_node_wrapper.sh
index 15c0e0d3..12f7085c 100755
--- a/bin/jenkins_node_wrapper.sh
+++ b/bin/jenkins_node_wrapper.sh
@@ -117,10 +117,10 @@ elif [[ "$*" =~ ^reproducible_setup_schroot_experimental_.*_.* ]] ; then
exec /srv/jenkins/bin/schroot-create.sh reproducible reproducible-experimental experimental ; croak "Exec failed";
elif [[ "$*" =~ ^reproducible_coreboot ]] ; then
exec /srv/jenkins/bin/reproducible_coreboot.sh ; croak "Exec failed";
-elif [ "$1" = "/srv/jenkins/bin/reproducible_openwrt.sh" ] && ( [ "$2" = "master" ] || [ "$2" = "1" ] || [ "$2" = "2" ] ) ; then
- exec /srv/jenkins/bin/reproducible_openwrt.sh "$2" "$3" "$4" "$5" "$6" "$7" "$8" ; croak "Exec failed";
-elif [ "$1" = "/srv/jenkins/bin/reproducible_lede.sh" ] && ( [ "$2" = "master" ] || [ "$2" = "1" ] || [ "$2" = "2" ] ) ; then
- exec /srv/jenkins/bin/reproducible_lede.sh "$2" "$3" "$4" "$5" "$6" "$7" "$8" ; croak "Exec failed";
+elif [[ "$*" =~ ^reproducible_openwrt ]] ; then
+ exec /srv/jenkins/bin/reproducible_openwrt.sh master ; croak "Exec failed";
+elif [[ "$*" =~ ^reproducible_lede ]] ; then
+ exec /srv/jenkins/bin/reproducible_lede.sh master ; croak "Exec failed";
elif [[ "$*" =~ ^reproducible_netbsd ]] ; then
exec /srv/jenkins/bin/reproducible_netbsd.sh ; croak "Exec failed";
elif [[ "$*" =~ ^reproducible_freebsd ]] ; then
diff --git a/bin/reproducible_openwrt_common.sh b/bin/reproducible_openwrt_common.sh
index 32a814eb..b3f4e314 100644
--- a/bin/reproducible_openwrt_common.sh
+++ b/bin/reproducible_openwrt_common.sh
@@ -1,6 +1,6 @@
#!/bin/bash
-# Copyright 2014-2016 Holger Levsen <holger@layer-acht.org>
+# Copyright 2014-2015 Holger Levsen <holger@layer-acht.org>
# © 2015 Reiner Herrmann <reiner@reiner-h.de>
# 2016 Alexander Couzens <lynxis@fe80.eu>
# released under the GPLv=2
@@ -258,20 +258,21 @@ build_two_times() {
TMPDIR_B1=$(ssh $HOST_B1 mktemp --tmpdir=/srv/workspace/chroots/ -d -t rbuild-lede-build-XXXXXXXX)
# TODO check tmpdir exist
- ssh $HOST_B1 $0 openwrt_build $TYPE $RUN $TARGET $CONFIG $TMPDIR_B1
+ SCRIPT="$0 slave"
+ ssh $HOST_B1 $SCRIPT openwrt_build $TYPE $RUN $TARGET $CONFIG $TMPDIR_B1
# rsync back
# copy logs and images
rsync -a $HOST_B1:$TMPDIR_B1/$RUN/ $TMPDIR/$RUN/
- ssh $HOST_B1 $0 openwrt_get_banner $TMPDIR_B1 $TYPE > $BANNER_HTML
- ssh $HOST_B1 $0 openwrt_cleanup_tmpdirs $TMPDIR_B1
+ ssh $HOST_B1 $SCRIPT openwrt_get_banner $TMPDIR_B1 $TYPE > $BANNER_HTML
+ ssh $HOST_B1 $SCRIPT openwrt_cleanup_tmpdirs $TMPDIR_B1
## HOST_B2
RUN=b2
TMPDIR_B2=$(ssh $HOST_A mktemp --tmpdir=/srv/workspace/chroots/ -d -t rbuild-lede-build-XXXXXXXX)
- ssh $HOST_B2 $0 openwrt_build $TYPE $RUN $TARGET $CONFIG $TMPDIR_B2
+ ssh $HOST_B2 $SCRIPT openwrt_build $TYPE $RUN $TARGET $CONFIG $TMPDIR_B2
rsync -a $HOST_B2:$TMPDIR_B2/$RUN/ $TMPDIR/$RUN/
- ssh $HOST_B2 $0 openwrt_cleanup_tmpdirs $TMPDIR_B2
+ ssh $HOST_B2 $SCRIPT openwrt_cleanup_tmpdirs $TMPDIR_B2
}
diff --git a/bin/reproducible_lede.sh b/bin/reproducible_lede.sh
index b7e7a9f1..534056c4 100755
--- a/bin/reproducible_lede.sh
+++ b/bin/reproducible_lede.sh
@@ -1,6 +1,6 @@
#!/bin/bash
-# Copyright 2014-2016 Holger Levsen <holger@layer-acht.org>
+# Copyright 2014-2015 Holger Levsen <holger@layer-acht.org>
# © 2015 Reiner Herrmann <reiner@reiner-h.de>
# 2016 Alexander Couzens <lynxis@fe80.eu>
# released under the GPLv=2
@@ -20,8 +20,9 @@ set -e
# * it's called from the reproducible_wrapper when running on the master
# * it's called from reproducible_opewnrt_common when doing remote builds
case $1 in
- 1|2)
- # execute build 1 or 2
+ slave)
+ # execute the slave
+ shift
$@
exit $?
;;
diff --git a/bin/reproducible_openwrt.sh b/bin/reproducible_openwrt.sh
index 495b0536..d3435900 100755
--- a/bin/reproducible_openwrt.sh
+++ b/bin/reproducible_openwrt.sh
@@ -1,6 +1,6 @@
#!/bin/bash
-# Copyright 2014-2016 Holger Levsen <holger@layer-acht.org>
+# Copyright 2014-2015 Holger Levsen <holger@layer-acht.org>
# © 2015 Reiner Herrmann <reiner@reiner-h.de>
# 2016 Alexander Couzens <lynxis@fe80.eu>
# released under the GPLv=2
@@ -20,8 +20,9 @@ set -e
# * it's called from the reproducible_wrapper when running on the master
# * it's called from reproducible_opewnrt_common when doing remote builds
case $1 in
- 1|2)
- # execute build 1 or 2
+ slave)
+ # execute the slave
+ shift
$@
exit $?
;;